Test Failing Verifications
open | ../tests/html/test_verifications.html |
assertFailureOnNext | Actual value '*test_verifications.html' did not match '*/tests/html/not_test_verifications.html' |
verifyLocation | */tests/html/not_test_verifications.html |
assertFailureOnNext | Actual value 'the text value' did not match 'not the text value' |
verifyValue | theText | not the text value
assertFailureOnNext | Actual value 'the text value' did match 'the text value' |
verifyNotValue | theText | the text value
assertFailureOnNext | Actual value 'the hidden value' did not match 'not the hidden value' |
verifyValue | theHidden | not the hidden value
assertFailureOnNext | Actual value 'this is the span' did not match 'this is not the span' |
verifyText | theSpan | this is not the span
assertFailureOnNext | false |
verifyTextPresent | this is not the span |
assertFailureOnNext | true |
verifyTextNotPresent | this is the span |
assertFailureOnNext | false |
verifyElementPresent | notTheSpan |
assertFailureOnNext | true |
verifyElementNotPresent | theSpan |
assertFailureOnNext | Actual value 'c' did not match 'a' |
verifyTable | theTable.2.0 | a
assertFailureOnNext | Expected '2' but was '1' |
verifySelected | theSelect | index=2
assertFailureOnNext | Actual value 'option2' did not match 'opt*3' |
verifySelected | theSelect | value=opt*3
assertFailureOnNext | Actual value 'second option' did not match 'third option' |
verifySelected | theSelect | third option
assertFailureOnNext | Actual value 'first option,second option,third\,\,option' did not match 'first\\,option,second option' |
verifySelectOptions | theSelect | first\\,option,second option
assertFailureOnNext | Actual value 'foo' did not match 'bar' |
verifyAttribute | theText@class | bar
assertFailureOnNext | Actual value 'foo' did match 'foo' |
verifyNotAttribute | theText@class | foo